@@ -1,6 +1,3 @@
-
-/*	$Id: tixDiITxt.c,v 1.2 2000/10/12 02:54:04 idiscovery Exp $	*/
-
 /*
  * tixDiImgTxt.c --
  *
@@ -491,7 +488,7 @@ static void Tix_ImageTextItemCalculateSize(iPtr)
     }
 
     if (itPtr->text) {
-	itPtr->numChars = -1;
+	itPtr->numChars = strlen(itPtr->text);
 	TixComputeTextGeometry(itPtr->stylePtr->font, itPtr->text,
 		itPtr->numChars, itPtr->stylePtr->wrapLength,
 		&itPtr->textW, &itPtr->textH);
