@@ -868,7 +868,7 @@ ImgXpmConfigureInstance(instancePtr)
     if (instancePtr->pixmap != None) {
 	Tk_FreePixmap(Tk_Display(instancePtr->tkwin), instancePtr->pixmap);
     }
-    TixpXpmFreeInstanceData(instancePtr, 0);
+    TixpXpmFreeInstanceData(instancePtr, 0, Tk_Display(instancePtr->tkwin));
 
     if (instancePtr->colors != NULL) {
 	int i;
@@ -1124,7 +1124,7 @@ ImgXpmFree(clientData, display)
     if (instancePtr->pixmap != None) {
 	Tk_FreePixmap(display, instancePtr->pixmap);
     }
-    TixpXpmFreeInstanceData(instancePtr, 1);
+    TixpXpmFreeInstanceData(instancePtr, 1, display);
 
     if (instancePtr->colors != NULL) {
 	int i;
@@ -1217,7 +1217,10 @@ ImgXpmCmdDeletedProc(clientData)
 
     masterPtr->imageCmd = NULL;
     if (masterPtr->tkMaster != NULL) {
-	Tk_DeleteImage(masterPtr->interp, Tk_NameOfImage(masterPtr->tkMaster));
+	if (Tk_MainWindow(masterPtr->interp) != NULL) {
+	    Tk_DeleteImage(masterPtr->interp,
+		    Tk_NameOfImage(masterPtr->tkMaster));
+	}
     }
 }
 
