@@ -1,6 +1,3 @@
-
-/*	$Id: tixItcl.h,v 1.1.1.1 2000/05/17 11:08:42 idiscovery Exp $	*/
-
 /*
  * tixItcl.h --
  *
@@ -15,32 +12,56 @@
  *
  */
 
-/*
- * With Tcl 8.0, namespaces moved from Itcl to Tcl, and so
- * the Tix hacks have to be used in any verison of 8.0,
- * regardless of the presence of Itcl...
- */
+#include <tix.h>
 
-#include "tix.h"
+#ifdef ITCL_2
 
 #ifndef _TCLINT
 #include <tclInt.h>
 #endif
 
 /*
- * Structure to store Tcl 8.0 name space information.
+ * Structure to store ITcl name space information.
  */
-
 typedef struct _TixItclNameSp {
     Interp *iPtr;
     CallFrame *savedVarFramePtr;
+    Itcl_ActiveNamespace nsToken;
 } TixItclNameSp;
 
 #define DECLARE_ITCL_NAMESP(x,i) \
     TixItclNameSp x; \
-    x.iPtr = (Interp*)(i);
+    x.iPtr = (Interp*)(i); \
+    x.nsToken = NULL;
 
-extern int		TixItclSetGlobalNameSp _ANSI_ARGS_((
+EXTERN int		TixItclSetGlobalNameSp _ANSI_ARGS_((
 			    TixItclNameSp * nameSpPtr, Tcl_Interp * interp));
-extern void		TixItclRestoreGlobalNameSp _ANSI_ARGS_((
+EXTERN void		TixItclRestoreGlobalNameSp _ANSI_ARGS_((
 			    TixItclNameSp * nameSpPtr, Tcl_Interp * interp));
+
+#else
+
+#ifdef TK_8_0_OR_LATER
+
+typedef struct _TixItclNameSp {
+    Tcl_CallFrame frame;
+} TixItclNameSp;
+
+#define DECLARE_ITCL_NAMESP(x,i) \
+    TixItclNameSp x;
+
+EXTERN int		TixItclSetGlobalNameSp _ANSI_ARGS_((
+			    TixItclNameSp * nameSpPtr, Tcl_Interp * interp));
+EXTERN void		TixItclRestoreGlobalNameSp _ANSI_ARGS_((
+			    TixItclNameSp * nameSpPtr, Tcl_Interp * interp));
+
+
+
+#else
+
+#define DECLARE_ITCL_NAMESP(x,i)
+#define TixItclSetGlobalNameSp(a,b)     (1)
+#define TixItclRestoreGlobalNameSp(a,b)
+
+#endif /* TK_8_0_OR_LATER */
+#endif /* ITCL_2 */
