@@ -11,14 +11,14 @@
  *
  */
 
-#include <tkPort.h>
-#include <tkInt.h>
+#include <tixPort.h>
 #include <tixInt.h>
 #include <tixDef.h>
 
 #define NUM_TAB_POINTS 6
 
-/* A data structure of the following type is kept for each
+/*
+ * A data structure of the following type is kept for each
  * widget managed by this file:
  */
 
@@ -58,7 +58,7 @@ typedef struct NoteBookFrameStruct {
     int isSlave;		/* if is in Slave mode, do not request for
 				 * germetry */
     /* Text drawing */
-    XFontStruct *fontPtr;	/* Information about text font, or NULL. */
+    TixFont font;		/* Information about text font, or NULL. */
     XColor *textColorPtr;	/* Color for drawing text. */
     XColor *disabledFg;		/* Foreground color when disabled.  NULL
 				 * means use normalFg with a 50% stipple
@@ -179,7 +179,7 @@ static Tk_ConfigSpec configSpecs[] = {
        TK_CONFIG_MONO_ONLY},
 
     {TK_CONFIG_FONT, "-font", "font", "Font",
-       DEF_NOTEBOOKFRAME_FONT, Tk_Offset(WidgetRecord, fontPtr), 0},
+       DEF_NOTEBOOKFRAME_FONT, Tk_Offset(WidgetRecord, font), 0},
 
     {TK_CONFIG_COLOR, "-foreground", "foreground", "Foreground",
        DEF_NOTEBOOKFRAME_FG_COLOR, Tk_Offset(WidgetRecord, textColorPtr),
@@ -290,8 +290,16 @@ static int		AddTab _ANSI_ARGS_((WidgetPtr wPtr, char * name,
 static void		DeleteTab _ANSI_ARGS_((Tab * tPtr));
 static void		CancelRedrawWhenIdle _ANSI_ARGS_((WidgetPtr wPtr));
 static void		ComputeGeometry _ANSI_ARGS_((WidgetPtr wPtr));
+static void		DrawTab _ANSI_ARGS_((WidgetPtr wPtr,
+			    Tab * tPtr, int x, int isActive,
+			    Drawable drawable));
 static Tab * 		FindTab _ANSI_ARGS_((Tcl_Interp *interp,
 			    WidgetPtr wPtr, char * name));
+static void		FocusTab _ANSI_ARGS_((WidgetPtr wPtr,
+			    Tab * tPtr, int x, Drawable drawable));
+static void		GetTabPoints _ANSI_ARGS_((
+			    WidgetPtr wPtr, Tab * tPtr,
+			    int x, XPoint *points));
 static void		ImageProc _ANSI_ARGS_((ClientData clientData,
 			    int x, int y, int width, int height,
 			    int imgWidth, int imgHeight));
@@ -361,7 +369,7 @@ Tix_NoteBookFrameCmd(clientData, interp, argc, argv)
     wPtr->disabledGC 		= None;
     wPtr->inActiveBorder 	= NULL;
     wPtr->focusBorder	 	= NULL;
-    wPtr->fontPtr	 	= NULL;
+    wPtr->font	 	= NULL;
     wPtr->textColorPtr	 	= NULL;
     wPtr->textGC	 	= None;
     wPtr->focusGC	 	= None;
@@ -436,7 +444,7 @@ WidgetCommand(clientData, interp, argc, argv)
 	if (argc != 3) {
 	    Tcl_AppendResult(interp, "wrong # args: should be \"",
 		argv[0], " ", argv[1], " name\"", (char *) NULL);
-	    result = TCL_ERROR;
+	    goto error;
 	}
 	else {
 	    if (strcmp(argv[2], "")==0) {
@@ -448,7 +456,6 @@ WidgetCommand(clientData, interp, argc, argv)
 		    wPtr->focus  = 0;
 		}
 		RedrawWhenIdle(wPtr);
-		result = TCL_OK;
 	    }
 	    else {
 		Tab * tPtr;
@@ -463,14 +470,13 @@ WidgetCommand(clientData, interp, argc, argv)
 			    wPtr->focus  = tPtr;
 			}
 			RedrawWhenIdle(wPtr);
-			result = TCL_OK;
 			goto done;
 		    }
 		}
 
 		Tcl_AppendResult(interp, "unknown tab \"",
 		    argv[0], "\"", (char *) NULL);
-		result = TCL_ERROR;
+		goto error;
 	    }
 	}
     }
@@ -478,15 +484,14 @@ WidgetCommand(clientData, interp, argc, argv)
 	if (argc < 3) {
 	    Tcl_AppendResult(interp, "wrong # args: should be ",
 		argv[0], " add name ?options?", (char *) NULL);
-	    result = TCL_ERROR;
+	    goto error;
 	}
 	else {
 	    if (AddTab(wPtr, argv[2], argv+3, argc-3)!= TCL_OK) {
-		result = TCL_ERROR;
+		goto error;
 	    } else {
 		WidgetComputeGeometry(wPtr);
 		RedrawWhenIdle(wPtr);
-		result = TCL_OK;
 	    }
 	}
     }
@@ -514,7 +519,7 @@ WidgetCommand(clientData, interp, argc, argv)
 	Tab * tPtr, * prev ;
 
 	if (argc != 3) {
-	    result = Tix_ArgcError(interp, argc, argv, 2, "page");
+	    Tix_ArgcError(interp, argc, argv, 2, "page");
 	    goto error;
 	}
 
@@ -545,7 +550,6 @@ WidgetCommand(clientData, interp, argc, argv)
 	DeleteTab(tPtr);
 	ComputeGeometry(wPtr);
 	RedrawWhenIdle(wPtr);
-	result = TCL_OK;
     }
     else if ((c == 'g') && (strncmp(argv[1], "geometryinfo", length) == 0)) {
 	char buff[20];
@@ -554,7 +558,6 @@ WidgetCommand(clientData, interp, argc, argv)
 	sprintf(buff, "%d %d", wPtr->width, wPtr->height);
 
 	Tcl_AppendResult(interp, buff, NULL);
-	result = TCL_OK;
     }
     else if ((c == 'i') && (strncmp(argv[1], "identify", length) == 0)) {
 	if (argc != 4) {
@@ -581,18 +584,16 @@ WidgetCommand(clientData, interp, argc, argv)
 
 		    if (x >= left && x <= right && tPtr->state ==tixNormalUid){
 			Tcl_AppendResult(interp, tPtr->name, NULL);
-			result = TCL_OK;
 			goto done;
 		    }
-
 		    left = right;
 		}
 	    }
 
+	    /*
+	     * An empty string is returned to indicate "nothing selected"
+	     */
 	    Tcl_ResetResult(interp);
-	    result = TCL_OK;	/* an empty string is returned to indicate
-				 * "nothing selected" */
-	    goto done;
 	}
     }
     else if ((c == 'i') && (strncmp(argv[1], "info", length) == 0)) {
@@ -604,22 +605,16 @@ WidgetCommand(clientData, interp, argc, argv)
 	    for (tPtr=wPtr->tabHead; tPtr; tPtr=tPtr->next) {
 		Tcl_AppendElement(interp, tPtr->name);
 	    }
-	    result = TCL_OK;
-	    goto done;
 	}
 	else if (argc == 3 && strcmp(argv[2], "active")==0 ) {
 	    if (wPtr->active) {
 		Tcl_AppendResult(interp, wPtr->active->name, NULL);
 	    }
-	    result = TCL_OK;
-	    goto done;
 	}
 	else if (argc == 3 && strcmp(argv[2], "focus")==0 ) {
 	    if (wPtr->focus) {
 		Tcl_AppendResult(interp, wPtr->focus->name, NULL);
 	    }
-	    result = TCL_OK;
-	    goto done;
 	}
 	else if (argc == 3 && strcmp(argv[2], "focusnext")==0 ) {
 	    Tab * next;
@@ -631,8 +626,6 @@ WidgetCommand(clientData, interp, argc, argv)
 		}
 		Tcl_AppendResult(interp, next->name, NULL);
 	    }
-	    result = TCL_OK;
-	    goto done;
 	}
 	else if (argc == 3 && strcmp(argv[2], "focusprev")==0 ) {
 	    Tab * prev, *tPtr;
@@ -651,8 +644,6 @@ WidgetCommand(clientData, interp, argc, argv)
 	    if (prev) {
 		Tcl_AppendResult(interp, prev->name, NULL);
 	    }
-	    result = TCL_OK;
-	    goto done;
 	}
 	else {
 	    Tcl_AppendResult(interp, "wrong number of arguments or ",
@@ -667,7 +658,7 @@ WidgetCommand(clientData, interp, argc, argv)
 	Tab * tPtr;
 
 	if (argc != 4) {
-	    result =  Tix_ArgcError(interp, argc, argv, 2, "option");
+	    Tix_ArgcError(interp, argc, argv, 2, "option");
 	    goto error;
 	}
 	if ((tPtr=FindTab(interp, wPtr, argv[2])) == NULL) {
@@ -680,7 +671,7 @@ WidgetCommand(clientData, interp, argc, argv)
 	Tab * tPtr;
 
 	if (argc < 3) {
-	    result =  Tix_ArgcError(interp, argc, argv, 2, 
+	    Tix_ArgcError(interp, argc, argv, 2, 
 		"page ?option value ...?");
 	    goto error;
 	}
@@ -778,7 +769,7 @@ WidgetConfigure(interp, wPtr, argc, argv, flags)
      */
     gcValues.foreground = wPtr->textColorPtr->pixel;
     gcValues.background = Tk_3DBorderColor(wPtr->bgBorder)->pixel;
-    gcValues.font = wPtr->fontPtr->fid;
+    gcValues.font = TixFontId(wPtr->font);
     gcValues.graphics_exposures = False;
     newGC = Tk_GetGC(wPtr->tkwin,
 	 GCBackground|GCForeground|GCFont|GCGraphicsExposures,
@@ -808,7 +799,7 @@ WidgetConfigure(interp, wPtr, argc, argv, flags)
 	gcValues.stipple = wPtr->gray;
 	mask = GCForeground|GCFillStyle|GCFont|GCStipple;
     }
-    gcValues.font = wPtr->fontPtr->fid;
+    gcValues.font = TixFontId(wPtr->font);
     newGC = Tk_GetGC(wPtr->tkwin, mask, &gcValues);
     if (wPtr->disabledGC != None) {
 	Tk_FreeGC(wPtr->display, wPtr->disabledGC);
@@ -1041,7 +1032,7 @@ static int TabConfigure(wPtr, tPtr, argv, argc)
 
     if (tPtr->text != NULL) {
 	tPtr->numChars = strlen(tPtr->text);
-	TkComputeTextGeometry(wPtr->fontPtr, tPtr->text, tPtr->numChars,
+	TixComputeTextGeometry(wPtr->font, tPtr->text, tPtr->numChars,
 	    tPtr->wrapLength, &tPtr->width, &tPtr->height);
     }
     else if (tPtr->image != NULL) {
@@ -1259,6 +1250,11 @@ static void DrawTab(wPtr, tPtr, x, isActive, drawable)
 	  case TK_ANCHOR_W: case TK_ANCHOR_CENTER: case TK_ANCHOR_E:
 	    drawY += extraH/2;
 	    break;
+	  case TK_ANCHOR_N: case TK_ANCHOR_NE: case TK_ANCHOR_NW:
+	    /*
+	     * Do nothing.
+	     */
+	    break;
 	}
     }
 
@@ -1268,7 +1264,7 @@ static void DrawTab(wPtr, tPtr, x, isActive, drawable)
 
     if (tPtr->text != NULL) {
 	if (tPtr->state == tixNormalUid) {
-	    TkDisplayText(wPtr->display, drawable, wPtr->fontPtr,
+	    TixDisplayText(wPtr->display, drawable, wPtr->font,
 	        tPtr->text, tPtr->numChars,
 	    	drawX, drawY,
 	        tPtr->width,
@@ -1276,7 +1272,7 @@ static void DrawTab(wPtr, tPtr, x, isActive, drawable)
 	        tPtr->underline,
 	        wPtr->textGC);
 	} else {
-	    TkDisplayText(wPtr->display, drawable, wPtr->fontPtr,
+	    TixDisplayText(wPtr->display, drawable, wPtr->font,
 	        tPtr->text, tPtr->numChars,
 	    	drawX, drawY,
 	        tPtr->width,
@@ -1488,7 +1484,7 @@ ComputeGeometry(wPtr)
 	    
 	    if (tPtr->text != NULL) {
 		tPtr->numChars = strlen(tPtr->text);
-		TkComputeTextGeometry(wPtr->fontPtr, tPtr->text,
+		TixComputeTextGeometry(wPtr->font, tPtr->text,
 		    tPtr->numChars, tPtr->wrapLength, 
 		    &tPtr->width, &tPtr->height);
 	    }
