@@ -19,8 +19,8 @@
  * 3) Merge aliases with specs
  *
  */
-#include <tkPort.h>
 #include <tk.h>
+#include <tixPort.h>
 #include <tixInt.h>
 
 static char *			FormatConfigInfo _ANSI_ARGS_((
@@ -40,7 +40,8 @@ int Tix_GetVar (interp, cPtr, widRec, flag)
     TixConfigSpec * spec;
     char * value;
 
-    if (spec = Tix_FindConfigSpecByName(interp, cPtr, flag)) {
+    spec = Tix_FindConfigSpecByName(interp, cPtr, flag);
+    if (spec != NULL) {
 	if (spec->isAlias) {
 	    flag = spec->realPtr->argvName;
 	} else {
@@ -57,6 +58,7 @@ int Tix_GetVar (interp, cPtr, widRec, flag)
     }
 }
 
+int
 Tix_QueryOneOption(interp, cPtr, widRec, flag)
     Tcl_Interp *interp;
     TixClassRecord *cPtr;
@@ -66,7 +68,8 @@ Tix_QueryOneOption(interp, cPtr, widRec, flag)
     TixConfigSpec * spec;
     char * list;
 
-    if (spec = Tix_FindConfigSpecByName(interp, cPtr, flag)) {
+    spec = Tix_FindConfigSpecByName(interp, cPtr, flag);
+    if (spec != NULL) {
 	list = FormatConfigInfo(interp, cPtr, widRec, spec);
 	Tcl_SetResult(interp, list, TCL_VOLATILE);
 
@@ -86,6 +89,7 @@ Tix_QueryOneOption(interp, cPtr, widRec, flag)
  * class structure.
  *
  */
+int
 Tix_QueryAllOptions (interp, cPtr, widRec)
     Tcl_Interp *interp;
     TixClassRecord * cPtr;
@@ -109,7 +113,8 @@ Tix_QueryAllOptions (interp, cPtr, widRec)
     return code;
 }
 
-TixConfigSpec * Tix_FindConfigSpecByName(interp, cPtr, flag)
+TixConfigSpec *
+Tix_FindConfigSpecByName(interp, cPtr, flag)
     Tcl_Interp * interp;
     TixClassRecord * cPtr;
     char * flag;
@@ -123,22 +128,24 @@ TixConfigSpec * Tix_FindConfigSpecByName(interp, cPtr, flag)
 
     classRec = cPtr->className;
 
-    /* First try to look up the confifspec in a hash table, 
-     * it should be faster
-     * (%% todo, hash table lookup only if there are more than a certain
-     * number of options (e.g. 10) in the class)
+    /*
+     * First try to look up the confifspec in a hash table, 
+     * it should be faster.
      */
 
     key = Tix_GetConfigSpecFullName(classRec, flag);
-    hashPtr = Tcl_FindHashEntry(&tixSpecTable, key);
+    hashPtr = Tcl_FindHashEntry(_TixGetHashTable(interp, "tixSpecTab", NULL),
+	    key);
     ckfree(key);
 
     if (hashPtr) {
 	return (TixConfigSpec *) Tcl_GetHashValue(hashPtr);
     }
 
-    /* The user may specified a partial name. Try to match, but will return
-     * error if we don't get exactly one match */
+    /*
+     * The user may specified a partial name. Try to match, but will
+     * return error if we don't get exactly one match.
+     */
     len = strlen(flag);
     for (configSpec=NULL,nMatch=0,i=0; i<cPtr->nSpecs; i++) {
 	if (strncmp(flag, cPtr->specs[i]->argvName, len) == 0) {
@@ -240,11 +247,14 @@ int Tix_CallConfigMethod(interp, cPtr, widRec, spec, value)
 
     sprintf(method, "config%s", spec->argvName);
 
-    if (c = Tix_FindMethod(interp, context, method)) {
+    c = Tix_FindMethod(interp, context, method);
+    if (c != NULL) {
 	argv[0] = value;
 	return Tix_CallMethod(interp, c, widRec, method, 1, argv);
     }
-    if (c = Tix_FindMethod(interp, context, "config")) {
+
+    c = Tix_FindMethod(interp, context, "config");
+    if (c != NULL) {
 	argv[0] = spec->argvName;
 	argv[1] = value;
 	return Tix_CallMethod(interp, c, widRec, "config", 2, argv);
@@ -333,6 +343,7 @@ int Tix_ChangeOneOption(interp, cPtr, widRec, spec, value, isDefault, isInit)
 	 */
 	if (interp->result && (*interp->result)) {
 	    /* value was overrided. Don't do anything */
+	    Tcl_ResetResult(interp);
 	} else {
 	    Tcl_SetVar2(interp, widRec, spec->argvName, value,TCL_GLOBAL_ONLY);
 	}
