@@ -1,6 +1,3 @@
-
-/*	$Id: tixPort.h,v 1.5 2004/03/28 02:44:57 hobbs Exp $	*/
-
 /*
  * tixPort.h --
  *
@@ -53,25 +50,36 @@
 #   endif
 #endif
 
+#ifdef TK_4_1_OR_LATER
+
 EXTERN Tcl_HashTable *	TixGetHashTable _ANSI_ARGS_((Tcl_Interp * interp,
-			    char * name, Tcl_InterpDeleteProc *deleteProc,
-                            int keyType));
+			    char * name, Tcl_InterpDeleteProc *deleteProc));
+#define _TixGetHashTable(i,n,p) TixGetHashTable(i,n,p)
+
+#else
+
+EXTERN Tcl_HashTable *	TixGetHashTable _ANSI_ARGS_((Tcl_Interp * interp,
+			    char * name));
+#define _TixGetHashTable(i,n,p) TixGetHashTable(i,n)
+
+#endif
+
+#if (TK_MAJOR_VERSION > 4)
 
 /*
- * Some pre-Tk8.0 style font handling. Should be updated to new Tk
- * font functions soon.
+ * The font handling is changed in Tk 8.0 and later
  */
 
 typedef Tk_Font TixFont;
 #define TixFontId(font) Tk_FontId(font)
 
 EXTERN void		TixComputeTextGeometry _ANSI_ARGS_((
-			    TixFont fontStructPtr, CONST84 char *string,
+			    TixFont fontStructPtr, char *string,
 			    int numChars, int wrapLength, int *widthPtr,
 			    int *heightPtr));
 EXTERN void		TixDisplayText _ANSI_ARGS_((Display *display,
 			    Drawable drawable, TixFont font,
-			    CONST84 char *string, int numChars, int x, int y,
+			    char *string, int numChars, int x, int y,
 			    int length, Tk_Justify justify, int underline,
 			    GC gc));
 
@@ -79,15 +87,27 @@ EXTERN void		TixDisplayText _ANSI_ARGS_((Display *display,
 #define TixNameOfFont Tk_NameOfFont
 #define TixGetFont Tk_GetFont
 
-/*
- * Tcl 8.4.a2 defines this macro that causes Tix compiled with
- * Tcl 8.4 to break in Tcl 8.3
- */
+#else
+
+typedef XFontStruct* TixFont;
+#define TixFontId(font) ((font)->fid)
+#define TixComputeTextGeometry TkComputeTextGeometry
+#define TixDisplayText TkDisplayText
+#define TixFreeFont Tk_FreeFontStruct
+#define TixNameOfFont Tk_NameOfFontStruct
+#define TixGetFont Tk_GetFontStruct
+
+EXTERN void		TkDisplayText _ANSI_ARGS_((Display *display,
+			    Drawable drawable, XFontStruct *fontStructPtr,
+			    char *string, int numChars, int x, int y,
+			    int length, Tk_Justify justify, int underline,
+			    GC gc));
+EXTERN void		TkComputeTextGeometry _ANSI_ARGS_((
+			    XFontStruct *fontStructPtr, char *string,
+			    int numChars, int wrapLength, int *widthPtr,
+			    int *heightPtr));
+
 
-#if defined(Tcl_InitHashTable) && defined(USE_TCL_STUBS)
-#undef Tcl_InitHashTable
-#define Tcl_InitHashTable \
-    (tclStubsPtr->tcl_InitHashTable)
 #endif
 
 #endif /* _TIX_PORT_H_ */
