@@ -272,188 +272,6 @@ void Tix_Exit(interp, code)
     }
     exit(code);
 }
-
-void Tix_OpenStdin(interp)
-    Tcl_Interp *interp;
-{
-    static int stdin_opened = 0;
-
-    if (stdin_opened ==  0)  {
-	Tk_CreateFileHandler(0, TK_READABLE, StdinProc, (ClientData) interp);
-	Prompt(interp, 0);
-	Tcl_DStringInit(&command);
-
-	stdin_opened = 1;
-    }
-}
-
-/*
- * Tix_ShellInputCmd -
- *
- * This command forces wish to read from the standard input. This makes
- * debugging a lot easier.
- *
- * If wish is already reading from stdin, this command has no effect.
- *
- */
-int Tix_ShellInputCmd(clientData, interp, argc, argv)
-    ClientData clientData;	/* Main window associated with
-				 * interpreter. */
-    Tcl_Interp *interp;		/* Current interpreter. */
-    int argc;			/* Number of arguments. */
-    char **argv;		/* Argument strings. */
-{
-
-#ifdef _WINDOWS
-    /*
-     * This command is only defined if we are running in the txwish.exe
-     * program, not in a Tix.DLL
-     */
-    Tcl_Eval(interp, "tixConsoleInit");
-    Tcl_ResetResult(interp);
-#else
-    Tix_OpenStdin(interp);
-#endif
-
-    return TCL_OK;
-}
-
-/*
- *----------------------------------------------------------------------
- *
- * StdinProc --
- *
- *	This procedure is invoked by the event dispatcher whenever
- *	standard input becomes readable.  It grabs the next line of
- *	input characters, adds them to a command being assembled, and
- *	executes the command if it's complete.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Could be almost arbitrary, depending on the command that's
- *	typed.
- *
- *----------------------------------------------------------------------
- */
-
-    /* ARGSUSED */
-static void
-StdinProc(clientData, mask)
-    ClientData clientData;		/* Not used. */
-    int mask;				/* Not used. */
-{
-#define BUFFER_SIZE 4000
-    char input[BUFFER_SIZE+1];
-    static int gotPartial = 0;
-    char *cmd;
-    int count;
-    Tcl_Interp * interp = (Tcl_Interp*)clientData;
-
-    count = read(fileno(stdin), input, BUFFER_SIZE);
-    if (isatty(0)) {
-	if (count <= 0) {
-	    if (!gotPartial) {
-		/* The user has typed the end-of-file key
-		 */
-		Tcl_GlobalEval(interp, "exit");
-		exit(1);
-	    } else {
-		count = 0;
-	    }
-	}
-    } else {
-	if (count <= 0) {
-	    /* End of file */
-	    Tk_CreateFileHandler(0, 0, StdinProc, (ClientData) interp);
-	    return;
-	}
-    }
-
-    cmd = Tcl_DStringAppend(&command, input, count);
-    if (count != 0) {
-	if ((input[count-1] != '\n') && (input[count-1] != ';')) {
-	    gotPartial = 1;
-	    goto prompt;
-	}
-	if (!Tcl_CommandComplete(cmd)) {
-	    gotPartial = 1;
-	    goto prompt;
-	}
-    }
-    gotPartial = 0;
-
-    /*
-     * Disable the stdin file handler while evaluating the command;
-     * otherwise if the command re-enters the event loop we might
-     * process commands from stdin before the current command is
-     * finished.  Among other things, this will trash the text of the
-     * command being evaluated.
-     */
-
-    Tk_CreateFileHandler(0, 0, StdinProc, (ClientData) interp);
-    Tcl_RecordAndEval(interp, cmd, 0);
-    Tk_CreateFileHandler(0, TK_READABLE, StdinProc, (ClientData) interp);
-    Tcl_DStringFree(&command);
-    if (interp->result != 0 && isatty(0)) {
-	printf("%s\n", interp->result);
-    }
-
-    /*
-     * Output a prompt.
-     */
-
-  prompt:
-    Prompt(interp, gotPartial);
-}
-
-/*
- *----------------------------------------------------------------------
- *
- * Prompt --
- *
- *	Issue a prompt on standard output, or invoke a script
- *	to issue the prompt.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	A prompt gets output, and a Tcl script may be evaluated
- *	in interp.
- *
- *----------------------------------------------------------------------
- */
-
-static void
-Prompt(interp, partial)
-    Tcl_Interp *interp;			/* Interpreter to use for prompting. */
-    int partial;			/* Non-zero means there already
-					 * exists a partial command, so use
-					 * the secondary prompt. */
-{
-    char *promptCmd;
-    int code;
-
-    promptCmd = Tcl_GetVar(interp,
-	partial ? "tcl_prompt2" : "tcl_prompt1", TCL_GLOBAL_ONLY);
-    if (promptCmd == NULL) {
-	defaultPrompt:
-	if (!partial && isatty(0)){
-	    fputs("% ", stdout);
-	}
-    } else {
-	code = Tcl_GlobalEval(interp, promptCmd);
-	if (code != TCL_OK) {
-	    Tcl_AddErrorInfo(interp,
-		    "\n    (script that generates prompt)");
-	    fprintf(stderr, "%s\n", interp->result);
-	    goto defaultPrompt;
-	}
-    }
-    fflush(stdout);
-}
 
 /*
  *----------------------------------------------------------------------
