@@ -27,7 +27,7 @@ tixWidgetClass tixDialogShell {
 	{-minwidth minWidth MinWidth 0}
 	{-minheight minHeight MinHeight 0}
 	{-transient transient Transient true}
-	{-parent parent Parent {}}
+	{-parent parent Parent ""}
     }
 }
 
@@ -35,14 +35,14 @@ tixWidgetClass tixDialogShell {
 #		Construct widget
 #----------------------------------------------------------------------
 
-proc tixDialogShell::ConstructWidget {w} {
+proc tixDialogShell:ConstructWidget {w} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructWidget
 
     # Set the title of this shell appropriately
     #
-    if {$data(-title) == {}} {
+    if {$data(-title) == ""} {
 	# dynamically sets the title
 	#
 	set data(-title) [winfo name $w]
@@ -51,7 +51,7 @@ proc tixDialogShell::ConstructWidget {w} {
 
     # Set the parent of this dialog shell
     #
-    if {$data(-parent) == {}} {
+    if {$data(-parent) == ""} {
 	set data(-parent) [winfo parent $w]
     }
 
@@ -62,7 +62,7 @@ proc tixDialogShell::ConstructWidget {w} {
 
 # The next procedures manage the dialog boxes
 #
-proc tixDialogShell::popup {w {parent {}}} {
+proc tixDialogShell:popup {w {parent ""}} {
     upvar #0 $w data
 
     # First update to make sure the boxes are the right size
@@ -71,7 +71,7 @@ proc tixDialogShell::popup {w {parent {}}} {
 
     # Then we set the position and update
     #
-    tixDialogShell::center $w $parent
+    tixDialogShell:center $w $parent
 
     # and now make it visible. Viola!  Centered over parent.
     #
@@ -84,14 +84,14 @@ proc tixDialogShell::popup {w {parent {}}} {
 # However, if the parent is smaller than this dialog, make this dialog
 # appear at parent(x,y) + (20,20)
 #
-proc tixDialogShell::center {w {parent {}}} {
+proc tixDialogShell:center {w {parent ""}} {
     upvar #0 $w data
 
     # Tell the WM that we'll do this ourselves.
     wm sizefrom $w user
     wm positionfrom $w user
 
-    if {$parent == {}} {
+    if {$parent == ""} {
 	set parent $data(-parent)
     }
     if [catch {set parent [winfo toplevel $parent]}] {
@@ -163,7 +163,7 @@ proc tixDialogShell::center {w {parent {}}} {
     }
 }
 
-proc tixDialogShell::popdown {w args} {
+proc tixDialogShell:popdown {w args} {
     wm withdraw $w
 }
 
