@@ -37,7 +37,7 @@ tixWidgetClass tixLabelEntry {
     }
 }
 
-proc tixLabelEntry::ConstructFramedWidget {w frame} {
+proc tixLabelEntry:ConstructFramedWidget {w frame} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructFramedWidget $frame
@@ -51,10 +51,22 @@ proc tixLabelEntry::ConstructFramedWidget {w frame} {
     set data(labelfg) [$data(w:label) cget -fg]
 }
 
+proc tixLabelEntryBind {} {
+  tixBind TixLabelEntry <FocusIn>  {
+    if {![tixStrEq [focus -displayof [set %W(w:entry)]] [set %W(w:entry)]]} {
+	focus [%W subwidget entry]
+	[set %W(w:entry)] selection from 0
+	[set %W(w:entry)] selection to end
+	[set %W(w:entry)] icursor end
+    }
+  }
+}
+
+
 #----------------------------------------------------------------------
 #                           CONFIG OPTIONS
 #----------------------------------------------------------------------
-proc tixLabelEntry::config-state {w value} {
+proc tixLabelEntry:config-state {w value} {
     upvar #0 $w data
 
     if {$value == "normal"} {
