@@ -30,7 +30,7 @@ tixWidgetClass tixNoteBook {
     }
 }
 
-proc tixNoteBook::InitWidgetRec {w} {
+proc tixNoteBook:InitWidgetRec {w} {
     upvar #0 $w data
 
     tixChainMethod $w InitWidgetRec
@@ -41,7 +41,7 @@ proc tixNoteBook::InitWidgetRec {w} {
     set data(pad-y2) 0
 }
 
-proc tixNoteBook::ConstructWidget {w} {
+proc tixNoteBook:ConstructWidget {w} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructWidget
@@ -49,27 +49,27 @@ proc tixNoteBook::ConstructWidget {w} {
     set data(w:top) [tixNoteBookFrame $w.nbframe -slave 1 -takefocus 1]
     set data(w:nbframe) $data(w:top)
 
-    bind $data(w:top) <ButtonPress-1> "tixNoteBook::MouseDown $w %x %y"
-    bind $data(w:top) <ButtonRelease-1> "tixNoteBook::MouseUp $w %x %y"
+    bind $data(w:top) <ButtonPress-1> "tixNoteBook:MouseDown $w %x %y"
+    bind $data(w:top) <ButtonRelease-1> "tixNoteBook:MouseUp $w %x %y"
 
-    bind $data(w:top) <B1-Motion> "tixNoteBook::MouseDown $w %x %y"
+    bind $data(w:top) <B1-Motion> "tixNoteBook:MouseDown $w %x %y"
 
-    bind $data(w:top) <Left>  "tixNoteBook::FocusNext $w prev"
-    bind $data(w:top) <Right> "tixNoteBook::FocusNext $w next"
+    bind $data(w:top) <Left>  "tixNoteBook:FocusNext $w prev"
+    bind $data(w:top) <Right> "tixNoteBook:FocusNext $w next"
 
-    bind $data(w:top) <Return> "tixNoteBook::SetFocusByKey $w"
-    bind $data(w:top) <space>  "tixNoteBook::SetFocusByKey $w"
+    bind $data(w:top) <Return> "tixNoteBook:SetFocusByKey $w"
+    bind $data(w:top) <space>  "tixNoteBook:SetFocusByKey $w"
 }
 
 #----------------------------------------------------------------------
 # Public methods
 #----------------------------------------------------------------------
-proc tixNoteBook::add {w child args} {
+proc tixNoteBook:add {w child args} {
     upvar #0 $w data
 
     set ret [eval tixChainMethod $w add $child $args]
 
-    set new_args {}
+    set new_args ""
     tixForEach {flag value} $args {
 	if {$flag != "-createcmd" && $flag != "-raisecmd"} {
 	    lappend new_args $flag
@@ -82,7 +82,7 @@ proc tixNoteBook::add {w child args} {
     return $ret
 }
 
-proc tixNoteBook::raise {w child} {
+proc tixNoteBook:raise {w child} {
     upvar #0 $w data
 
     tixChainMethod $w raise $child
@@ -92,7 +92,7 @@ proc tixNoteBook::raise {w child} {
     }
 }
 
-proc tixNoteBook::delete {w child} {
+proc tixNoteBook:delete {w child} {
     upvar #0 $w data
 
     tixChainMethod $w delete $child
@@ -102,7 +102,7 @@ proc tixNoteBook::delete {w child} {
 #----------------------------------------------------------------------
 # Private methods
 #----------------------------------------------------------------------
-proc tixNoteBook::Resize {w} {
+proc tixNoteBook:Resize {w} {
     upvar #0 $w data
 
     # We have to take care of the size of the tabs so that 
@@ -123,7 +123,7 @@ proc tixNoteBook::Resize {w} {
     tixChainMethod $w Resize
 }
 
-proc tixNoteBook::MouseDown {w x y} {
+proc tixNoteBook:MouseDown {w x y} {
     upvar #0 $w data
 
     focus $data(w:top)
@@ -133,12 +133,12 @@ proc tixNoteBook::MouseDown {w x y} {
     set data(w:down) $name
 }
 
-proc tixNoteBook::MouseUp {w x y} {
+proc tixNoteBook:MouseUp {w x y} {
     upvar #0 $w data
 
     set name [$data(w:top) identify $x $y]
 
-    if {$name != {} && $name == $data(w:down) && [$data(w:top) pagecget $name -state] == "normal" } {
+    if {$name != "" && $name == $data(w:down) && [$data(w:top) pagecget $name -state] == "normal" } {
         $data(w:top) activate $name
         tixCallMethod $w raise $name
     } else {
@@ -153,14 +153,14 @@ proc tixNoteBook::MouseUp {w x y} {
 #
 #----------------------------------------------------------------------
 
-proc tixNoteBook::FocusNext {w dir} {
+proc tixNoteBook:FocusNext {w dir} {
     upvar #0 $w data
 
-    if {[$data(w:top) info focus] == {}} {
+    if {[$data(w:top) info focus] == ""} {
 	set name [$data(w:top) info active]
 	$data(w:top) focus $name
 
-	if {$name != {}} {
+	if {$name != ""} {
 	    return
 	}
     } else {
@@ -169,12 +169,12 @@ proc tixNoteBook::FocusNext {w dir} {
    }
 }
 
-proc tixNoteBook::SetFocusByKey {w} {
+proc tixNoteBook:SetFocusByKey {w} {
     upvar #0 $w data
 
     set name [$data(w:top) info focus]
 
-    if {$name != {} && [$data(w:top) pagecget $name -state] == "normal"} {
+    if {$name != "" && [$data(w:top) pagecget $name -state] == "normal"} {
 	tixCallMethod $w raise $name
 	$data(w:top) activate $name
     }
@@ -216,7 +216,7 @@ proc tixNoteBookFind {w char} {
 	    return $match
 	}
     }
-    return {}
+    return ""
 }
 
 proc tixTraverseToNoteBook {w char} {
