@@ -191,7 +191,7 @@ proc _tixDialogDestroy {w} {
 proc _tixInitMainWindow {w} {
     upvar #0 $w data
 
-    set data(dialogs) {}
+    set data(dialogs) ""
 
     bind $w <Destroy>    +[bind Toplevel <Destroy>]
     bind $w <Map>        +[bind Toplevel <Map>]
@@ -207,7 +207,7 @@ proc _tixInitMainWindow {w} {
 # If this wish does not support mwm, the following line prevent code
 # that uses "mwm" from breaking.
 #
-if {[info commands mwm] == {}} {
+if {[info commands mwm] == ""} {
     proc mwm {args} {}
 }
 
