@@ -39,7 +39,7 @@ tixWidgetClass tixScrolledText {
     }
 }
 
-proc tixScrolledText::ConstructWidget {w} {
+proc tixScrolledText:ConstructWidget {w} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructWidget
@@ -54,14 +54,14 @@ proc tixScrolledText::ConstructWidget {w} {
     set data(pw:client) $data(w:text)
 }
 
-proc tixScrolledText::SetBindings {w} {
+proc tixScrolledText:SetBindings {w} {
     upvar #0 $w data
 
     tixChainMethod $w SetBindings
 
     $data(w:text) config \
-	-xscrollcommand "tixScrolledText::XScroll $w"\
-	-yscrollcommand "tixScrolledText::YScroll $w"
+	-xscrollcommand "tixScrolledText:XScroll $w"\
+	-yscrollcommand "tixScrolledText:YScroll $w"
 
     $data(w:hsb) config -command "$data(w:text) xview"
     $data(w:vsb) config -command "$data(w:text) yview"
@@ -71,16 +71,19 @@ proc tixScrolledText::SetBindings {w} {
 #
 #		option configs
 #----------------------------------------------------------------------
-proc tixScrolledText::config-takefocus {w value} {
+proc tixScrolledText:config-takefocus {w value} {
     upvar #0 $w data
   
     $data(w:text) config -takefocus $value
 }	
 
-proc tixScrolledText::config-scrollbar {w value} {
+proc tixScrolledText:config-scrollbar {w value} {
     upvar #0 $w data
   
     if {[string match "auto*" $value]} {
+	# There is a bug in TK that prevents the "auto" from operating
+	# properly - sometimes you'd get "flashing" effect when
+	# scrollbars keep apprearing and going away.
 	set value "both"
     }
     set data(-scrollbar) $value
@@ -104,13 +107,13 @@ proc tixScrolledText::config-scrollbar {w value} {
 #----------------------------------------------------------------------
 # virtual functions to query the client window's scroll requirement
 #----------------------------------------------------------------------
-proc tixScrolledText::GeometryInfo {w mW mH} {
+proc tixScrolledText:GeometryInfo {w mW mH} {
     upvar #0 $w data
 
     return [list "$data(x,first) $data(x,last)" "$data(y,first) $data(y,last)"]
 }
 
-proc tixScrolledText::XScroll {w first last} {
+proc tixScrolledText:XScroll {w first last} {
     upvar #0 $w data
 
     set data(x,first) $first
@@ -118,10 +121,10 @@ proc tixScrolledText::XScroll {w first last} {
 
     $data(w:hsb) set $first $last
 
-    tixWidgetDoWhenIdle tixScrolledWidget::Configure $w
+    tixWidgetDoWhenIdle tixScrolledWidget:Configure $w
 }
 
-proc tixScrolledText::YScroll {w first last} {
+proc tixScrolledText:YScroll {w first last} {
     upvar #0 $w data
 
     set data(y,first) $first
@@ -129,5 +132,5 @@ proc tixScrolledText::YScroll {w first last} {
     
     $data(w:vsb) set $first $last
 
-    tixWidgetDoWhenIdle tixScrolledWidget::Configure $w
+    tixWidgetDoWhenIdle tixScrolledWidget:Configure $w
 }
