@@ -1,6 +1,6 @@
 #!/bin/sh
 # the next line restarts using tclsh \
-exec tclsh7.5 "$0" "$@"
+exec tclsh "$0" "$@"
 
 source [file join [file dirname [info script]] doxx.tcl]
 
@@ -32,8 +32,8 @@ if test "$UNAME" != ""; then
     fi
 
     if test "$uname" != "$ac_cv_prog_uname"; then
-        echo "Running on a different architecture. Can't use cached values"
-	echo "Removing config.cache and running configure again"
+        echo "Running on a different machine/architecture. Can't use cached values"
+	echo "Removing config.cache and running configure again ..."
 	rm -f config.cache
         CMDLINE="$0 $*"
 	exec $CMDLINE
@@ -49,30 +49,7 @@ if test "$INSTALL" = "./install.sh"; then
 fi
 
 #--------------------------------------------------------------------
-#	strdup() is not a POSIX call and many machines don't have it
-#--------------------------------------------------------------------
-
-AC_CHECK_FUNC(strdup, , AC_DEFINE(NO_STRDUP))
-
-#--------------------------------------------------------------------
-#	Check whether there is an strcasecmp function on this system.
-#	This is a bit tricky because under SCO it's in -lsocket and
-#	under Sequent Dynix it's in -linet.
-#--------------------------------------------------------------------
-
-AC_CHECK_FUNC(strcasecmp, tcl_ok=1, tcl_ok=0)
-if test "$tcl_ok" = 0; then
-    AC_CHECK_LIB(socket, strcasecmp, tcl_ok=1, tcl_ok=0)
-fi
-if test "$tcl_ok" = 0; then
-    AC_CHECK_LIB(inet, strcasecmp, tcl_ok=1, tcl_ok=0)
-fi
-if test "$tcl_ok" = 0; then
-    AC_DEFINE(NO_STRCASECMP)
-fi
-
-#--------------------------------------------------------------------
-#	Version information about this DP release.
+#	Version information about this TIX release.
 #--------------------------------------------------------------------
 
 TIX_VERSION=4.1
@@ -113,6 +90,42 @@ AC_PROG_RANLIB
 AC_HAVE_HEADERS(unistd.h limits.h)
 AC_PROG_MAKE_SET
 
+#--------------------------------------------------------------------
+#	strdup() is not a POSIX call and many machines don't have it
+#--------------------------------------------------------------------
+
+AC_CHECK_FUNC(strdup, , AC_DEFINE(NO_STRDUP))
+
+#--------------------------------------------------------------------
+#	unsigned char is not supported by some non-ANSI compilers.
+#--------------------------------------------------------------------
+
+AC_MSG_CHECKING([unsigned char])
+AC_TRY_COMPILE([#include <stdio.h>],[
+     unsigned char c = 'c';
+], tcl_ok=supported, tcl_ok="not supported")
+
+AC_MSG_RESULT($tcl_ok)
+if test "$tcl_ok" = supported; then
+    AC_DEFINE(UCHAR_SUPPORTED)
+fi
+
+#--------------------------------------------------------------------
+#	Check whether there is an strcasecmp function on this system.
+#	This is a bit tricky because under SCO it's in -lsocket and
+#	under Sequent Dynix it's in -linet.
+#--------------------------------------------------------------------
+
+AC_CHECK_FUNC(strcasecmp, tcl_ok=1, tcl_ok=0)
+if test "$tcl_ok" = 0; then
+    AC_CHECK_LIB(socket, strcasecmp, tcl_ok=1, tcl_ok=0)
+fi
+if test "$tcl_ok" = 0; then
+    AC_CHECK_LIB(inet, strcasecmp, tcl_ok=1, tcl_ok=0)
+fi
+if test "$tcl_ok" = 0; then
+    AC_DEFINE(NO_STRCASECMP)
+fi
 }
 
 # LocatePkg75 --
@@ -144,7 +157,7 @@ if test "$val" != ""; then
         exit 1
     fi
 else
-    dirs="../../../pkg@@_V_PKG_VER_@@*"
+    dirs="../../../pkg@@_V_PKG_VER_@@"
     PKG_SRC_DIR="no-no"
     for i in $dirs; do
         if test -d $i; then
@@ -224,12 +237,23 @@ AC_ARG_ENABLE(sam,
 if test "$ok" = "yes"; then
     TIX_BUILD_SAM="yes"
     TIX_SAM_TARGETS='$(SAM_TARGETS)'
-    TIX_SAM_INSTALL=_install_sam_
 else
     TIX_BUILD_SAM="no"
 fi
 }
 
+if $ENABLE_SAM {
+    if $SAM_EXE {
+	p {
+	    TIX_SAM_INSTALL="_install_sam_exe_ _install_sam_lib_"
+	}
+    } else {
+	p {
+	    TIX_SAM_INSTALL=_install_sam_lib_
+	}
+    }
+}
+
 ##
 ## Tcl 7.4 --> we need to find the location of the X libs, etc.
 ##
